import { endConversationService, getOptionsEndsService, transferConversationService } from "@/feature/messenger/services/chat/OptionsConversationsService";
import useConfigChatStore from "@/feature/messenger/store/chat_store/useConfigChatStore";
import useConversationsStore from "@/feature/messenger/store/chat_store/useConversationsStore";
import useMessagesStore from "@/feature/messenger/store/chat_store/useMessagesStore";
import { useTranslation } from "@/hooks/useTranslation";
import { useState } from "react";
import toast from 'react-hot-toast';

export const useOptionsConversation = (selectedConversation: any) => {
    const [openModal, setOpenModal] = useState(false);
    const [endConversationData, setEndConversationData] = useState([]);
    const id_chatbot = useConfigChatStore(state => state.idChatbot);
    const agentsLogged = useConfigChatStore(state => state.agentsLogged);
    const [loading, setLoading] = useState(false);
    const actionsConversation = useConversationsStore(state => state.actions);
    const actionsMessages = useMessagesStore(state => state.actions);
    const { trans } = useTranslation();
    

    const handleOpenModal = () => {
        setOpenModal(!openModal)
    }

    const getOptionsEnds = () => {
        getOptionsEndsService(id_chatbot,selectedConversation.sesion).then((res) => {
            const data = res.data
            setEndConversationData(data)
        })
    }

    const handleSubmitEndConversation = async (option:string,valida:boolean) => {
        if (option.trim() == '' && valida) {
            toast.error(trans('modal_conversations_end_message_alert_select_option_title'));
        }
        setLoading(true)
        const res = await endConversationService(id_chatbot,selectedConversation.sesion,option)
        const response = res;        
        if (response.success == true) {
            toast.success(`${trans('modal_conversations_end_message_alert_create_title')} ${selectedConversation.sesion}`);
            actionsConversation.removeConversation(selectedConversation)
            actionsMessages.clearListMessages()
        }
        setLoading(false)
    }

    const handleSubmitTranferConversation = async (transIdUser:string,commentary:string) => {
        setLoading(true)
        const res = await transferConversationService(id_chatbot,selectedConversation.sesion,transIdUser,commentary);
        if (res.success == true) {
            toast.success(`${trans('modal_conversations_transfer_message_alert_create_title')} ${selectedConversation.sesion}`);
            actionsConversation.removeConversation(selectedConversation)
            actionsMessages.clearListMessages()
        }else{
            toast.error(`${trans('modal_conversations_transfer_message_alert_error_option_title')} ${selectedConversation.sesion}`);
        }
        setLoading(false)
    }

    return {
        openModal,
        handleOpenModal,
        endConversationData,
        selectedConversation,
        getOptionsEnds,
        loading,
        setLoading,
        handleSubmitEndConversation,
        agentsLogged,
        handleSubmitTranferConversation
    }
}